"""Define a SmartCocoon Thermostat class."""
# pylint: disable=too-few-public-methods,too-many-instance-attributes

from typing import Any


class Thermostat:  # pylint: disable=too-many-instance-attributes
    """Define the thermostat."""

    def __init__(self, data: dict[str, Any]) -> None:
        """Initialize."""
        self._identifier: int = data["id"]
        self._name: str = data["name"]
        self._thermostat_id: id = data["thermostat_id"]
        self._token: str = data["token"]
        self._hvac_mode: str = data["hvac_mode"]
        self._hvac_state: str = data["hvac_state"]
        self._temperature: float = data["temperature"]
        self._target_temperature: float = data["target_temperature"]
        self._vendor: str = data["vendor"]

    @property
    def identifier(self) -> str:
        """Return Thermostat id.

        This is a numerical ID generated by SmartCocoon
        This value can change if the thermostat is re-added to
        an cloud account
        """
        return self._identifier

    @property
    def name(self) -> str:
        """Return thermostat name."""
        return self._name

    @property
    def thermostat_id(self) -> str:
        """Return thermostat id."""
        return self._thermostat_id

    @property
    def token(self) -> str:
        """Return token ."""
        return self._token

    @property
    def hvac_mode(self) -> str:
        """Return HVAC mode"""
        return self._hvac_mode

    @property
    def hvac_state(self) -> str:
        """Return HVAC state"""
        return self._hvac_state

    @property
    def temperature(self) -> str:
        """Return is temperature."""
        return self._temperature

    @property
    def target_temperature(self) -> str:
        """Return target temperature"""
        return self._target_temperature

    @property
    def vendor(self) -> str:
        """Return vendor"""
        return self._vendor



"""Tests SmartCocoon api module."""
import asyncio
import logging
import time
from os import environ
from os.path import dirname, join

import aiohttp
from dotenv import load_dotenv

from pysmartcocoon.manager import SmartCocoonManager

# Load the account information
dotenv_path = join(dirname(__file__), ".env")
load_dotenv(dotenv_path)

USERNAME = environ.get("USERNAME")
PASSWORD = environ.get("PASSWORD")
FAN_ID = environ.get("FAN_ID")

logging.basicConfig(level=logging.DEBUG)
_LOGGER: logging.Logger = logging.getLogger(__name__)


async def test_integration_fan_control() -> None:
    """Test authentification then control fan."""

    async with aiohttp.ClientSession() as session:
        # Init manager
        manager = SmartCocoonManager(session=session)

        if not await manager.async_start_services(
            username=USERNAME, password=PASSWORD
        ):
            _LOGGER.debug("Authentication failed")
            return

        # Test fan controls
        wait_for = 5

        await manager.async_fan_turn_on(FAN_ID)
        time.sleep(wait_for)
        await manager.async_set_fan_speed(FAN_ID, 50)
        time.sleep(wait_for)
        await manager.async_set_fan_speed(FAN_ID, 100)
        time.sleep(wait_for)
        await manager.async_set_fan_auto(FAN_ID)
        time.sleep(wait_for)
        await manager.async_set_fan_eco(FAN_ID)
        time.sleep(wait_for)
        await manager.async_fan_turn_off(FAN_ID)
        time.sleep(wait_for)


asyncio.run(test_integration_fan_control())



"""Define a SmartCocoon Rocation class."""
# pylint: disable=too-few-public-methods,too-many-instance-attributes

from typing import Any


class Location:  # pylint: disable=too-many-instance-attributes
    """Define the location."""

    def __init__(self, data: dict[str, Any]) -> None:
        """Initialize."""
        self._identifier: int = data["id"]
        self._name: str = data["name"]
        self._street: str = data["location"]["street"]
        self._city: str = data["location"]["city"]
        self._state: str = data["location"]["state"]
        self._country: str = data["location"]["country"]
        self._postal_code: str = data["location"]["postal_code"]

    @property
    def identifier(self) -> str:
        """Return location id"""
        return self._identifier

    @property
    def name(self) -> str:
        """Return location mame"""
        return self._name

    @property
    def street(self) -> str:
        """Return street"""
        return self._street

    @property
    def city(self) -> str:
        """Return city"""
        return self._city

    @property
    def country(self) -> str:
        """Return country"""
        return self._country

    @property
    def postal_code(self) -> str:
        """Return postal code"""
        return self._postal_code
